# Biomimetic

## A Python library for biomimetic cell models in neural networks

Refer to the three papers: [Bio-mimetic approach in digital artificial neuro-science](https://ieeexplore.ieee.org/document/7560120) [Biomimetic Cells: A New Frontier in Brain Informatics](https://ieeexplore.ieee.org/abstract/document/8603044) [Advanced Biomimetic Cells Architecture for Parallel Operations in Artificial Intelligence](https://ieeexplore.ieee.org/abstract/document/8851116)